/*****************************************
*  Select proper distribution centers    *
******************************************/

using CP;
 
/*******
* Data *
*******/

int NbCenters = ...;
int NbServicies = ...;
range RCenters = 1..NbCenters;
range RServicies = 1..NbServicies;

int MinCenters = ...;
int MinProfit = ...;

int Cost[RCenters] = ...;                
int Profit[RServicies][RCenters] = ...;    

/*********************
* Decision variables *
*********************/

// 1 if center open, 0 otherwise  
dvar boolean open[RCenters];     
                  
/*********************
* Objective function *
*********************/

//total profit based on the number of open centers
dexpr int totalProfit = sum( c in RCenters, s in RServicies ) Profit[s][c] * open[c];

//total cost based on the opening cost of centers
dexpr int totalCost = sum( c in RCenters ) open[c]*Cost[c];

maximize totalProfit - totalCost;
    
/**************
* Constraints *
**************/

subject to {
  
  // minimal number of open centers for each service s
  forall( s in RServicies )
    sum( c in RCenters: Profit[s][c]>0 ) open[c] >= MinCenters;  
  
  // minimal profit for each service s 
  forall( s in RServicies )
    sum( c in RCenters ) Profit[s][c] * open[c] >= MinProfit; 
         
}